# Rustic AI Marvin

[Rustic AI](https://www.rustic.ai/) module which provides text classification and extraction agent using [Marvin](https://www.askmarvin.ai/welcome/what_is_marvin/).

## Installing

```shell
pip install rusticai-marvin
```
**Note:** It depends on [rusticai-core](https://pypi.org/project/rusticai-core/)

## Building from Source

```shell
poetry install --with dev
poetry build
```
